      program showParam
c         to read namelist and write them
c         This  may be used to get all the parameter list.
c         
      implicit none
#include "Zmanagerp.h"
c          testing creadParm
      call cerrorMsg(
     * 'You can get Defaults by putting &Param &end', 1)
      call creadParam(5)
      call cwriteParam(ErrorOut, 1)
      end
#include "BlockData/cblkGene.h"
